#ifndef HISTO_H
#define HISTO_H
/*
* MPIA - GEIRS project
*
* "@(#) $Id$"
*
*/

#include <string>
#include <vector>
#include <valarray>

using namespace std ;

/** 
* @since 2013-01-29
* @author Richard J. Mathar
*/
class Histo {

public:
	/** The counts on a per-bin basis. 
	* Provides by its length an explicit count of the bins.
	*/
	vector<int> cts  ;

	/** The cumulative counts on a per-bin basis. 
	* cumCts[i] contains sum_{k=0..n} cts[k].
	* @since 2013-12-04
	*/
	vector<int> cumCts  ;

	/** The smallest range of the first bin
	*/
	double strt ;

	/** The width of each bin
	*/
	double stride ;

	/** Percentile abscissas.
	* [0] the 3 sigma level (left), [1] the 2 sigm left, [2] the 1 sigma left,
	* [3] the median, [4] the 1 sigma right, [5] the 2 sigma right, [6] the 3 sigma right.
	*/
	double perc[7] ;

	/** Minimum and maximum value and arithmetic mean.
	* @since 2013-06-07
	*/
	double mimax[3] ;

	/** Some kind of file name or tag attached to this statistics.
	*/
	string name ;

	Histo() ;
	Histo(const valarray<float> & arr, const int Nbin, const double range[], string & nam) ;
	Histo(const valarray<float> & arr, const int Nbin, string & nam) ;
	Histo(const valarray<float> & arr, string & nam) ;

	static int valRange(const valarray<float> & arr, double mimax[2]) ;

	// ~Histo() ;

	void dumpFil(const char *fname) ;


protected:

private:
	void init(const valarray<float> & arr, const int Nbin, const double range[]) ;

} ; /* Histo */

int fsort(const void * v1, const void * v2) ;

#endif /* HISTO_H */
